==> redpesk-cli_3.15.0.orig.tar.gz: redpesk-cli-3.15.0/rpxxxapi/ladapi/lad_constants.go <==
/*
Copyright © 2021-2023 IoT.bzh Company
Contact: https://www.iot.bzh/licensing

This file is part of the redpesk-cli project, the redpesk command line tool.

$RP_BEGIN_LICENSE$
Commercial License Usage
 Licensees holding valid commercial IoT.bzh licenses may use this file in
 accordance with the commercial license agreement provided with the
 Software or, alternatively, in accordance with the terms contained in
 a written agreement between you and The IoT.bzh Company. For licensing terms
 and conditions see https://www.iot.bzh/terms-conditions. For further
 information use the contact form at https://www.iot.bzh/contact.

GNU General Public License Usage
 Alternatively, this file may be used under the terms of the GNU General
 Public license version 3. This license is as published by the Free Software
 Foundation and appearing in the file LICENSE.GPLv3 included in the packaging
 of this file. Please review the following information to ensure the GNU
 General Public License requirements will be met
 https://www.gnu.org/licenses/gpl-3.0.html.
$RP_END_LICENSE$
*/

package ladapi

const (
	// Logs prefix
	ladLogPrefix = "[RPLAD] "

	// URL prefix
	urlPrefix = "/api/v1"

	// Cookie key
	ladCookieKey = "rp_lad_id"

	// Authorization constants
	authorizationHeader = "Authorization"

	// Redpesk LAD routes

	// Misc command
	versionRoute = "/version"

	// Exec command
	execRoute = "/exec"

	// Symlink command
	symlinkRoute = "/symlink"

	// Iotpkg command
	iotpkgRoute                = "/iotpkg"
	iotpkglocalbuildRoute      = iotpkgRoute + "/localbuild"
	iotpkglocalcrossbuildRoute = iotpkgRoute + "/localcrossbuild"
	iotpkgarchiveRoute         = iotpkgRoute + "/archive"

	// Terminal command
	terminalRoute       = "/terminal"
	terminalSizeRoute   = terminalRoute + "/size"
	terminalSignalRoute = terminalRoute + "/signal"

	// Events routes
	subscribeEvtRoute   = "/event/subscribe"
	unsubscribeEvtRoute = "/event/unsubscribe"

	// Errors messages
	initRPAPIInterfaceError = "either logR pointer or httpCli pointer is nil"
	execCmdNilError         = "the RPLADExecCmdStruct pointer needs to be different than nil"
	iotpkgCmdNilError       = "the RPLADIotpkgCmdStruct pointer needs to be different than nil"
	winSizeNilError         = "the RPLADWinResize pointer needs to be different than nil"
	procSignalNilError      = "the RPLADSignalSend pointer needs to be different than nil"

	// Debug messages
)

==> redpesk-cli_3.18.0.orig.tar.gz: redpesk-cli-3.18.0/rpxxxapi/ladapi/lad_constants.go <==
/*
Copyright © 2021-2023 IoT.bzh Company
Contact: https://www.iot.bzh/licensing

This file is part of the redpesk-cli project, the redpesk command line tool.

$RP_BEGIN_LICENSE$
Commercial License Usage
 Licensees holding valid commercial IoT.bzh licenses may use this file in
 accordance with the commercial license agreement provided with the
 Software or, alternatively, in accordance with the terms contained in
 a written agreement between you and The IoT.bzh Company. For licensing terms
 and conditions see https://www.iot.bzh/terms-conditions. For further
 information use the contact form at https://www.iot.bzh/contact.

GNU General Public License Usage
 Alternatively, this file may be used under the terms of the GNU General
 Public license version 3. This license is as published by the Free Software
 Foundation and appearing in the file LICENSE.GPLv3 included in the packaging
 of this file. Please review the following information to ensure the GNU
 General Public License requirements will be met
 https://www.gnu.org/licenses/gpl-3.0.html.
$RP_END_LICENSE$
*/

package ladapi

const (
	// Logs prefix
	ladLogPrefix = "[RPLAD] "

	// URL prefix
	urlPrefix = "/api/v1"

	// Cookie key
	ladCookieKey = "rp_lad_id"

	// Authorization constants
	authorizationHeader = "Authorization"

	// Redpesk LAD routes

	// Misc command
	versionRoute = "/version"

	// Exec command
	execRoute = "/exec"

	// Symlink command
	symlinkRoute = "/symlink"

	// Iotpkg command
	iotpkgRoute                = "/iotpkg"
	iotpkgLocalbuildRoute      = iotpkgRoute + "/localbuild"
	iotpkgLocalcrossbuildRoute = iotpkgRoute + "/localcrossbuild"
	iotpkgArchiveRoute         = iotpkgRoute + "/archive"
	iotpkgServiceRoute         = iotpkgRoute + "/service"
	iotpkgMetadataRoute        = iotpkgRoute + "/metadata"
	iotpkgInitRoute            = iotpkgRoute + "/init"
	iotpkgRPBuildRoute         = iotpkgRoute + "/rpbuild"
	iotpkgCleanMockRoute       = iotpkgRoute + "/cleanmock"

	// Terminal command
	terminalRoute       = "/terminal"
	terminalSizeRoute   = terminalRoute + "/size"
	terminalSignalRoute = terminalRoute + "/signal"

	// Events routes
	subscribeEvtRoute   = "/event/subscribe"
	unsubscribeEvtRoute = "/event/unsubscribe"

	// Errors messages
	initRPAPIInterfaceError = "either logR pointer or httpCli pointer is nil"
	execCmdNilError         = "the RPLADExecCmdStruct pointer needs to be different than nil"
	iotpkgCmdNilError       = "the RPLADIotpkgCmdStruct pointer needs to be different than nil"
	winSizeNilError         = "the RPLADWinResize pointer needs to be different than nil"
	procSignalNilError      = "the RPLADSignalSend pointer needs to be different than nil"

	// Debug messages
)
